@@ -41,10 +41,10 @@
 #' See source file \code{ext_query.R} for an example on how implement new
 #' extensions.
 #'
-#' @param q      a \code{RSTACQuery} object expressing a STAC query
+#' @param q   a \code{RSTACQuery} object expressing a STAC query
 #' criteria.
 #'
-#' @param ...    entries with format \code{<field> <operator> <value>}.
+#' @param ... entries with format \code{<field> <operator> <value>}.
 #'
 #' @seealso \code{\link{stac_search}}, \code{\link{post_request}},
 #' \code{\link{endpoint}}, \code{\link{before_request}},
@@ -58,7 +58,7 @@
 #' \donttest{
 #' stac("https://brazildatacube.dpi.inpe.br/stac/") %>%
 #'   stac_search(collections = "CB4_64_16D_STK-1") %>%
-#'   ext_query("bdc:tile" %in% c("022024")) %>%
+#'   ext_query("bdc:tile" %in% "022024") %>%
 #'   post_request()
 #' }
 #'
@@ -148,6 +148,17 @@ after_response.ext_query <- function(q, res) {
   RSTACDocument(content = content, q = q, subclass = "STACItemCollection")
 }
 
+#' @export
+parse_params.ext_query <- function(q, params) {
+
+  # call super class
+  params <- parse_params.search(q, params)
+
+  params$query <- .parse_values_keys(params$query)
+
+  params
+}
+
 #' @title Utility function
 #'
 #' @param op     a \code{character} with operation to be searched.
@@ -169,3 +180,33 @@ after_response.ext_query <- function(q, res) {
                    "in 'ext_query()' function."), op)
   values[[op]][[1]]
 }
+
+#' @title Utility function
+#'
+#' @param query a \code{list} with parameters to be provided in requests.
+#'
+#' @return a \code{list} with parsed parameters.
+#'
+#' @noRd
+.parse_values_keys <- function(query) {
+
+  uniq_keys <- names(query)
+
+  entries <- lapply(uniq_keys, function(k) {
+    ops <- names(query[[k]])
+
+    values <- lapply(ops, function(op){
+      query[[k]][[op]]
+    })
+
+    names(values) <- ops
+
+    res <- lapply(ops, .parse_values_op, values)
+    names(res) <- ops
+    return(res)
+  })
+
+  names(entries) <- uniq_keys
+
+  entries
+}
