@@ -1,12 +1,12 @@
 context("test_internal_functions")
 
 testthat::test_that("internals functions", {
-  vcr::use_cassette("test_internal_functions",{
+  vcr::use_cassette("test_internal_functions", {
 
     # skip cran check test
     testthat::skip_on_cran()
 
-    stac_obj <- rstac::stac("http://brazildatacube.dpi.inpe.br/stac/")
+    stac_obj <- rstac::stac("https://brazildatacube.dpi.inpe.br/stac/")
 
     # check_subclass object
     testthat::expect_null(
